{% load i18n static %}
{% if cl.search_fields %}
    <div class="app-search pull-right">
        <form id="changelist-search" method="get">
            <div>
                <input type="search" class="form-control form-control-sm" size="40" name="{{ search_var }}"
                       value="{{ cl.query }}" id="searchbar" autofocus placeholder="{% trans 'Search' %}"/>
                <button type="submit" class="app-search__button" value="{% trans 'Search' %}"><i
                        class="fa fa-search"></i></button>
                {% if show_result_count %}
                    <span class="small quiet">{% blocktrans count counter=cl.result_count %}{{ counter }} result
                        {% plural %}{{ counter }} results{% endblocktrans %} (<a
                            href="?{% if cl.is_popup %}_popup=1{% endif %}">{% if cl.show_full_result_count %}
                        {% blocktrans with full_result_count=cl.full_result_count %}{{ full_result_count }} total
                        {% endblocktrans %}{% else %}{% trans "Show all" %}{% endif %}</a>)</span>
                {% endif %}
                {% for pair in cl.params.items %}
                    {% if pair.0 != search_var %}<input type="hidden" name="{{ pair.0 }}" value="{{ pair.1 }}"/>
                    {% endif %}
                {% endfor %}
            </div>
        </form>
    </div>
{% endif %}
