{% extends "admin/base_site.html" %}
{% load i18n admin_urls static admin_modify %}

{% block extrahead %}{{ block.super }}
    <script type="text/javascript" src="{% url 'admin:jsi18n' %}"></script>
    {{ media }}
{% endblock %}

{% block extrastyle %}{{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% static 'admin/css/forms.css' %}"/>{% endblock %}

{% block coltype %}container{% endblock %}

{% block bodyclass %}{{ block.super }} app-{{ opts.app_label }} model-{{ opts.model_name }} change-form{% endblock %}

{% if not is_popup %}
    {% block breadcrumbs %}
        <ul class="app-breadcrumb breadcrumb">
            <li class="breadcrumb-item"><a href="{% url 'admin:index' %}"><i
                    class="fa fa-home fa-lg"></i>{% trans 'Home' %}</a></li>

            {% ifequal opts.app_label "auth" %}
                <li class="breadcrumb-item">
                    <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{% trans 'Authentication' %}</a>
                </li>
            {% else %}
                <li class="breadcrumb-item">
                    <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a>
                </li>
            {% endifequal %}

            <li class="breadcrumb-item">
                {% if has_change_permission %}
                    <a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>
                {% else %}
                    {{ opts.verbose_name_plural|capfirst }}
                {% endif %}</li>
            <li class="breadcrumb-item">
                {% if add %}
                    {% blocktrans with name=opts.verbose_name %}
                        Add {{ name }}
                    {% endblocktrans %}
                {% else %}
                    {{ original|truncatewords:"18" }}
                {% endif %}
            </li>
        </ul>
    {% endblock %}
{% endif %}

{% block object-tools %}
    {% if change %}{% if not is_popup %}
        <div class="object-tools object-tools-mr" style="margin-right:16%">
            {% block object-tools-items %}
                {% url opts|admin_urlname:'history' original.pk|admin_urlquote as history_url %}
                <a href="{% add_preserved_filters history_url %}"
                   class="btn btn-primary btn-sm historylink">{% trans "History" %}</a>
                {% if has_absolute_url %}<a href="{{ absolute_url }}"
                                            class="btn btn-primary btn-sm viewsitelink">{% trans "View on site" %}</a>
                {% endif %}
            {% endblock %}
        </div>
    {% endif %}{% endif %}
{% endblock %}

{% block content %}
    <div id="content-main" class="row">

        <form {% if has_file_field %}enctype="multipart/form-data" {% endif %}action="{{ form_url }}" method="post"
              style="width:100%" id="{{ opts.model_name }}_form" novalidate>
            {% csrf_token %}{% block form_top %}{% endblock %}
            <div class="col">
                {% if is_popup %}<input type="hidden" name="{{ is_popup_var }}" value="1"/>{% endif %}
                {% if to_field %}<input type="hidden" name="{{ to_field_var }}" value="{{ to_field }}"/>{% endif %}
                {% if save_on_top %}{% block submit_buttons_top %}{% submit_row %}{% endblock %}{% endif %}
                {% if errors %}
                    <p class="alert alert-dismissible alert-danger mt-0">
                        <button class="close" type="button" data-dismiss="alert">×</button>
                        {% if errors|length == 1 %}{% trans "Please correct the error below." %}{% else %}
                            {% trans "Please correct the errors below." %}{% endif %}
                    </p>
                    {{ adminform.form.non_field_errors }}
                {% endif %}

                {% block field_sets %}
                    {% for fieldset in adminform %}
                        <div class="tile">
                            {% include "admin/includes/fieldset.html" %}
                        </div>
                    {% endfor %}
                {% endblock %}

                {% block after_field_sets %}{% endblock %}

                {% block inline_field_sets %}
                    {% for inline_admin_formset in inline_admin_formsets %}
                        {% include inline_admin_formset.opts.template %}
                    {% endfor %}
                {% endblock %}

                {% block after_related_objects %}{% endblock %}

                {% block submit_buttons_bottom %}{% submit_row %}{% endblock %}

                {% block admin_change_form_document_ready %}
                    <script type="text/javascript"
                            id="django-admin-form-add-constants"
                            src="{% static 'admin/js/change_form.js' %}"
                            {% if adminform and add %}
                            data-model-name="{{ opts.model_name }}"
                            {% endif %}>
                    </script>
                {% endblock %}

                {% prepopulated_fields_js %}

            </div>
        </form>
    </div>
{% endblock %}
